==> scala-k8s-objects_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/PersistentVolumeStatus.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** PersistentVolumeStatus is the current status of a persistent volume. */
final case class PersistentVolumeStatus(
  message : Option[String] = None,
  phase : Option[String] = None,
  reason : Option[String] = None
) {

  /** Returns a new data with message set to new value */
  def withMessage(value: String) : PersistentVolumeStatus = copy(message = Some(value))
  /** if message has a value, transforms to the result of function*/
  def mapMessage(f: String => String) : PersistentVolumeStatus = copy(message = message.map(f))

  /** Returns a new data with phase set to new value */
  def withPhase(value: String) : PersistentVolumeStatus = copy(phase = Some(value))
  /** if phase has a value, transforms to the result of function*/
  def mapPhase(f: String => String) : PersistentVolumeStatus = copy(phase = phase.map(f))

  /** Returns a new data with reason set to new value */
  def withReason(value: String) : PersistentVolumeStatus = copy(reason = Some(value))
  /** if reason has a value, transforms to the result of function*/
  def mapReason(f: String => String) : PersistentVolumeStatus = copy(reason = reason.map(f))
}

object PersistentVolumeStatus {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.PersistentVolumeStatus, T] = new Encoder[io.k8s.api.core.v1.PersistentVolumeStatus, T] {
        def apply(o: io.k8s.api.core.v1.PersistentVolumeStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("message", o.message)
            .write("phase", o.phase)
            .write("reason", o.reason)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, PersistentVolumeStatus] = new Decoder[T, PersistentVolumeStatus] {
      def apply(t: T): Either[String, PersistentVolumeStatus] = for {
          obj <- ObjectReader(t)
          message <- obj.readOpt[String]("message")
          phase <- obj.readOpt[String]("phase")
          reason <- obj.readOpt[String]("reason")
      } yield PersistentVolumeStatus (
          message = message,
          phase = phase,
          reason = reason
        )
    }
}

==> scala-k8s-objects_3-0.5.1-sources.jar: io/k8s/api/core/v1/PersistentVolumeStatus.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** PersistentVolumeStatus is the current status of a persistent volume. */
final case class PersistentVolumeStatus(
  message : Option[String] = None,
  phase : Option[String] = None,
  reason : Option[String] = None
) {

  /** Returns a new data with message set to new value */
  def withMessage(value: String) : PersistentVolumeStatus = copy(message = Some(value))
  /** if message has a value, transforms to the result of function*/
  def mapMessage(f: String => String) : PersistentVolumeStatus = copy(message = message.map(f))

  /** Returns a new data with phase set to new value */
  def withPhase(value: String) : PersistentVolumeStatus = copy(phase = Some(value))
  /** if phase has a value, transforms to the result of function*/
  def mapPhase(f: String => String) : PersistentVolumeStatus = copy(phase = phase.map(f))

  /** Returns a new data with reason set to new value */
  def withReason(value: String) : PersistentVolumeStatus = copy(reason = Some(value))
  /** if reason has a value, transforms to the result of function*/
  def mapReason(f: String => String) : PersistentVolumeStatus = copy(reason = reason.map(f))
}

object PersistentVolumeStatus {

    implicit val encoder : Encoder[io.k8s.api.core.v1.PersistentVolumeStatus] = new Encoder[io.k8s.api.core.v1.PersistentVolumeStatus] {
        def apply[T : Builder](o: io.k8s.api.core.v1.PersistentVolumeStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("message", o.message)
            .write("phase", o.phase)
            .write("reason", o.reason)
            .build
        }
    }

    implicit val decoder: Decoder[PersistentVolumeStatus] = new Decoder[PersistentVolumeStatus] {
      def apply[T : Reader](t: T): Either[String, PersistentVolumeStatus] = for {
          obj <- ObjectReader(t)
          message <- obj.readOpt[String]("message")
          phase <- obj.readOpt[String]("phase")
          reason <- obj.readOpt[String]("reason")
      } yield PersistentVolumeStatus (
          message = message,
          phase = phase,
          reason = reason
        )
    }
}
